@@ -5,6 +5,7 @@ import shutil
 from . import util 
 from .orchestrator import Orchestration
 from . import admin
+import pandas as pd
 
 l = logging.getLogger("pandem")
 
@@ -89,6 +90,11 @@ def main(a):
     action="store_true", 
     help="Delete all files and database elements and restore system defaults", 
   )
+  reset_parser.add_argument(
+    "--scripts",
+    action="store_true",
+    help="Restore the default script folder in pandem-home"
+  )
   reset_parser.add_argument(
     "--covid19-datahub", 
     action="store_true", 
@@ -105,9 +111,19 @@ def main(a):
     help="Reset influenza net datasource to system defaults", 
   )
   reset_parser.add_argument(
-    "--ecdc-covid19-variants", 
+    "--ecdc-covid19", 
     action="store_true", 
-    help="Reset ecdc-covid19-variants datasource to system defaults", 
+    help="Reset ecdc-covid19 datasource to system defaults", 
+  )
+  reset_parser.add_argument(
+    "--ecdc-covid19-simulated", 
+    action="store_true", 
+    help="Reset ecdc-covid19 simulated datasource to system defaults", 
+  )
+  reset_parser.add_argument(
+    "--serotracker", 
+    action="store_true", 
+    help="Reset serotracker datasource to system defaults", 
   )
   reset_parser.add_argument(
     "--pandem-partners-template", 
@@ -124,9 +140,41 @@ def main(a):
     action="store_true", 
     help="Reset pandem medisys system defaults", 
   )
-  
+  reset_parser.add_argument(
+    "--flights",
+    action="store_true",
+    help="Reset pandem flight related information to system defaults", 
+  )
+
   reset_parser.set_defaults(func = do_reset)
 
+  # Launch pandem source listt command
+  start_parser = subs.add_parser("list", help = "List elements on this Pandem-Source instance")
+  start_parser.add_argument(
+    "--sources",
+    action="store_true",
+    help="List existing sources in this instance", 
+  )
+  
+  start_parser.add_argument(
+    "--missing-sources",
+    action="store_true",
+    help="List sources embedded on pandemSource package not present on this instance", 
+  )
+  start_parser.add_argument(
+    "--package-sources",
+    action="store_true",
+    help="List sources embedded on pandemSource package", 
+  )
+  start_parser.add_argument(
+    "--missing-package-sources",
+    action="store_true",
+    help="List existing sources in this instance not present on pandemSource package", 
+  )
+
+  start_parser.set_defaults(func = do_list)
+
+  
   util.check_pandem_home()
   #calling handlers
   func = None
@@ -141,7 +189,7 @@ def main(a):
 # handlers
 def do_start_dev(debug = True, no_acquire = False, retry_failed = False, restart_job = 0, not_retry_active = False, no_app = True, force_acquire = False, no_nlp = False):
   from types import SimpleNamespace
-  return do_start(SimpleNamespace(**{"debug":True, "no_acquire":no_acquire, "retry_failed":retry_failed, "limit_collection":None, "restart_job":restart_job, "no_app":no_app, "not_retry_active":not_retry_active, "force_acquire":force_acquire, "no_nlp":False}))
+  return do_start(SimpleNamespace(**{"debug":True, "no_acquire":no_acquire, "retry_failed":retry_failed, "limit_collection":None, "restart_job":restart_job, "no_app":no_app, "not_retry_active":not_retry_active, "force_acquire":force_acquire, "no_nlp": no_nlp}))
 
 # handlers
 def do_start(args, *other):
@@ -180,7 +228,7 @@ def do_start(args, *other):
     orch = orchestrator_ref.proxy()
     storage_proxy = orch.get_actor("storage").get().proxy()
     dls_files = storage_proxy.list_files('source-definitions').get()
-    dls_dicts = [storage_proxy.read_file(file_name['path']).get() for file_name in dls_files]
+    dls_dicts = [storage_proxy.read_file(file_name['path']).get() for file_name in dls_files if file_name['path'].endswith(".json")]
     
     for source_name in args.limit_collection.split(","):
       dls = list(filter(lambda dls: dls['scope']['source'] == source_name, dls_dicts))[0]
@@ -200,9 +248,11 @@ def do_reset(args, *other):
   if args.restore_factory_defaults:
     admin.delete_all()
     admin.reset_default_folders("input-local", "input-local-defaults", "dfcustom", "scripts", "variables", "indicators", "img")
+  if args.scripts:
+    admin.reset_default_folders("scripts")
   if args.variables or args.restore_factory_defaults:
-    admin.reset_variables(in_home = True)
-  if args.covid19_datahub or args.ecdc_covid19_variants or args.restore_factory_defaults:
+    admin.reset_variables()
+  if args.covid19_datahub or args.ecdc_covid19 or args.restore_factory_defaults:
     admin.reset_source("nuts-eurostat")
     admin.reset_source("ICD-10-diseases-list")
   if args.pandem_partners_template or args.restore_factory_defaults:
@@ -231,8 +281,16 @@ def do_reset(args, *other):
     admin.reset_source("covid19-template-local-regions-THL")
   if args.covid19_datahub or args.restore_factory_defaults:
     admin.reset_source("covid19-datahub")
-  if args.ecdc_covid19_variants or args.restore_factory_defaults:
-    admin.reset_source("ecdc-covid19-variants")    
+  if args.ecdc_covid19_simulated or args.restore_factory_defaults:
+    admin.reset_source("ecdc-covid19-age-group-variants")
+  if args.ecdc_covid19 or args.restore_factory_defaults:
+    admin.reset_source("ecdc-covid19-variants")
+    admin.reset_source("ecdc-covid19-age-group")
+    admin.reset_source("ecdc-covid19-measures")
+    admin.reset_source("ecdc-covid19-daily")
+  if args.serotracker or args.restore_factory_defaults:
+    admin.reset_source("geonames-countries")    
+    admin.reset_source("serotracker")    
   if args.ecdc_atlas or args.restore_factory_defaults:
     admin.reset_source("ecdc-atlas-influenza")    
   if args.influenzanet or args.restore_factory_defaults:
@@ -240,7 +298,18 @@ def do_reset(args, *other):
   if args.twitter or args.restore_factory_defaults:
     admin.reset_source("twitter")    
   if args.medisys or args.restore_factory_defaults:
-    admin.reset_source("medisys")    
+    admin.reset_source("medisys")
+  if args.flights or args.restore_factory_defaults:
+    admin.reset_source("ourairports")
+    admin.reset_source("opensky-network-coviddataset")
+
+def do_list(args, *other):
+  if args.sources or args.missing_sources or args.package_sources or args.missing_package_sources:
+    sources = admin.list_sources(local = args.sources, default = args.package_sources, missing_local = args.missing_sources, missing_default = args.missing_package_sources)
+    for line in pd.DataFrame(sources,columns=["Source", "Tag"]).to_string().split("\n"):
+        print(line)
+
+
 
 if __name__ == "__main__":
   main(sys.argv[1] if len(sys.argv)>1 else None)
