@@ -2,16 +2,19 @@ from . import worker
 import os
 from . import util 
 from .storage import CacheValue
+from . import admin
 import itertools
 import json
 import datetime
 import numpy
 from collections import defaultdict
 from .util import JsonEncoder
-import logging as l
+import logging
 import pickle
 import copy
 
+l = logging.getLogger("pandem.variable")
+
 class Variables(worker.Worker):
     def __init__(self, name, orchestrator_ref, settings): 
         super().__init__(name = name, orchestrator_ref = orchestrator_ref, settings = settings)
@@ -28,7 +31,7 @@ class Variables(worker.Worker):
     def get_variables(self):
         if self._variables is None:
           dic_variables = dict()
-          var_list=self._storage_proxy.read_file('variables/variables.json').get()
+          var_list=admin.read_variables_definitions()
           for var in var_list: 
               if not var["base_variable"]:            
                   base_dict = var.copy()
@@ -89,7 +92,7 @@ class Variables(worker.Worker):
                 file_name = file['name']
                 if file_name == 'default.json':
                     target_files.append(file)
-                else:
+                elif file_name.endswith(".json"):
                     can_ignore = False
                     for var_val in file_name.split('.')[:-1]:
                         var = var_val.split('=')[0]
@@ -305,7 +308,7 @@ class Variables(worker.Worker):
         key_map = {tuple((k, (v if var not in modifiers or not k in modifiers[var] else modifiers[var][k])) for k, v in comb):comb for comb in combinations}
         if tuples is not None:
           for t in tuples:
-            keys = sorted(attr for attr in t["attrs"].keys() if dico_vars[attr]["type"] in types)
+            keys = sorted(attr for attr in t["attrs"].keys() if dico_vars[attr]["type"] in types and (t["attrs"][attr] is not None or (var in modifiers and attr in modifiers[var])))
             if tuple((k, t["attrs"][k]) for k in keys) in key_map:
               key = key_map[tuple((k, t["attrs"][k]) for k in keys)]
               filter_value = {k:v for k, v in t["attrs"].items() if k in (filter if filter is not None else [])}  
@@ -373,7 +376,7 @@ class Variables(worker.Worker):
                 key = []
                 key.append(("indicator", obs_name))
                 to_ignore = ['not_characteristic', 'date']
-                key.extend([(k, v) for k,v in t["attrs"].items() if k in var_dic and var_dic[k]["type"] not in to_ignore or k == "source"])
+                key.extend([(k, v) for k,v in t["attrs"].items() if v is not None and k in var_dic and var_dic[k]["type"] not in to_ignore or k == "source"])
                 key.sort(key = lambda p:p[0])
                 key = tuple(key)
           
